@@ -30,11 +30,8 @@ pub const OCI_TYPE_LAYER_TAR: &str = "application/vnd.oci.image.layer.v1.tar";
 // Note that payload data (non-metadata) should go over a pipe file descriptor.
 const MAX_MSG_SIZE: usize = 32 * 1024;
 
+// Introduced in https://github.com/containers/skopeo/pull/1523
 static BASE_PROTO_VERSION: Lazy<semver::VersionReq> =
-    Lazy::new(|| semver::VersionReq::parse("0.2.0").unwrap());
-
-// https://github.com/containers/skopeo/pull/1523
-static SEMVER_0_2_3: Lazy<semver::VersionReq> =
     Lazy::new(|| semver::VersionReq::parse("0.2.3").unwrap());
 
 #[derive(Serialize)]
@@ -226,11 +223,8 @@ impl ImageProxy {
         // Verify semantic version
         let protover = r.impl_request::<String, _, ()>("Initialize", []).await?.0;
         let protover = semver::Version::parse(protover.as_str())?;
-        let supported = if cfg!(feature = "proxy_v0_2_3") {
-            &*SEMVER_0_2_3
-        } else {
-            &*BASE_PROTO_VERSION
-        };
+        // Previously we had a feature to opt-in to requiring newer versions using `if cfg!()`.
+        let supported = &*BASE_PROTO_VERSION;
         if !supported.matches(&protover) {
             return Err(anyhow!(
                 "Unsupported protocol version {} (compatible: {})",
@@ -358,23 +352,44 @@ impl ImageProxy {
         Ok(r)
     }
 
-    /// Fetch the manifest.
+    /// Fetch the manifest as raw bytes, converted to OCI if necessary.
+    /// The original digest of the unconverted manifest is also returned.
     /// For more information on OCI manifests, see <https://github.com/opencontainers/image-spec/blob/main/manifest.md>
-    pub async fn fetch_manifest(&self, img: &OpenedImage) -> Result<(String, Vec<u8>)> {
+    pub async fn fetch_manifest_raw_oci(&self, img: &OpenedImage) -> Result<(String, Vec<u8>)> {
         let (digest, fd) = self.impl_request("GetManifest", [img.0]).await?;
         Ok((digest, self.read_all_fd(fd).await?))
     }
 
+    /// Fetch the manifest.
+    /// For more information on OCI manifests, see <https://github.com/opencontainers/image-spec/blob/main/manifest.md>
+    pub async fn fetch_manifest(
+        &self,
+        img: &OpenedImage,
+    ) -> Result<(String, oci_spec::image::ImageManifest)> {
+        let (digest, raw) = self.fetch_manifest_raw_oci(img).await?;
+        let manifest = serde_json::from_slice(&raw)?;
+        Ok((digest, manifest))
+    }
+
     /// Fetch the config.
     /// For more information on OCI config, see <https://github.com/opencontainers/image-spec/blob/main/config.md>
-    #[cfg(feature = "proxy_v0_2_3")]
-    pub async fn fetch_config(&self, img: &OpenedImage) -> Result<Vec<u8>> {
+    pub async fn fetch_config_raw(&self, img: &OpenedImage) -> Result<Vec<u8>> {
         let (_, fd) = self
             .impl_request::<(), _, _>("GetFullConfig", [img.0])
             .await?;
         self.read_all_fd(fd).await
     }
 
+    /// Fetch the config.
+    /// For more information on OCI config, see <https://github.com/opencontainers/image-spec/blob/main/config.md>
+    pub async fn fetch_config(
+        &self,
+        img: &OpenedImage,
+    ) -> Result<oci_spec::image::ImageConfiguration> {
+        let raw = self.fetch_config_raw(img).await?;
+        Ok(serde_json::from_slice(&raw)?)
+    }
+
     /// Fetch a blob identified by e.g. `sha256:<digest>`.
     /// <https://github.com/opencontainers/image-spec/blob/main/descriptor.md>
     ///
